@@ -11,6 +11,10 @@ from virtualbox import library
 Add helper code to the default IMachine class.
 """
 
+try:
+    basestring = basestring
+except:
+    basestring = (str, bytes)
 
 # Extend and fix IMachine :) 
 class IMachine(library.IMachine):
@@ -52,8 +56,9 @@ class IMachine(library.IMachine):
             progress.wait_for_completion(-1)
             media = []
         
-        # if delete - let's remove the settings folder too
-        if delete:
+        # if delete - At some point in time virtualbox didn't do a full cleanup 
+        #             of this dir. Let's double check it has been cleaned up.
+        if delete and os.path.exists(settings_dir):
             shutil.rmtree(settings_dir)
 
         return media
@@ -82,7 +87,7 @@ class IMachine(library.IMachine):
         vbox = virtualbox.VirtualBox()
 
         if snapshot_name_or_id is not None:
-            if snapshot_name_or_id in [str, unicode]:
+            if isinstance(snapshot_name_or_id, basestring):
                 snapshot = self.find_snapshot(snapshot_name_or_id)
             else:
                 snapshot = snapshot_name_or_id
@@ -126,20 +131,6 @@ class IMachine(library.IMachine):
             vbox.register_machine(vm_clone)
         return vm_clone
 
-    # BUG: xidl describes this function as deleteConfig.  The interface seems
-    #      to export plain "delete" instead... 
-    def delete_config(self, media):
-        if not isinstance(media, list):
-            raise TypeError("media can only be an instance of type list")
-        for a in media[:10]:
-            if not isinstance(a, library.IMedium):
-                raise TypeError(\
-                        "array can only contain objects of type IMedium")
-        progress = self._call("delete", in_p=[media])
-        progress = library.IProgress(progress)
-        return progress
-    delete_config.__doc__ = library.IMachine.delete_config.__doc__
-
     # Add a helper to make locking and building a session simple
     def create_session(self, lock_type=library.LockType.shared,
                    session=None):
@@ -192,14 +183,14 @@ class IMachine(library.IMachine):
     # BUG: xidl describes this function as exportTo.  The interface seems
     #      to export plain "export" instead... 
     def export_to(self, appliance, location):
-        if not isinstance(appliance, IAppliance):
+        if not isinstance(appliance, library.IAppliance):
             msg = "appliance can only be an instance of type IAppliance"
             raise TypeError(msg)
         if not isinstance(location, basestring):
             raise TypeError("value is not an instance of basestring")
         description = self._call("export",
                      in_p=[appliance, location])
-        description = IVirtualSystemDescription(description)
+        description = library.IVirtualSystemDescription(description)
         return description
     export_to.__doc__ = library.IMachine.export_to.__doc__
 
